==> mui-extension-4.1.3.tgz: package/lib/ExpensionStepper/ExpensionStep.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import { useEffect, useRef } from 'react';
import { Box, Collapse, Icon } from '@mui/material';
import { colorSuccess } from '../_core/style/color';
var animationDuration = 300;
export var ExpensionStep = function (_a) {
    var disabled = _a.disabled, done = _a.done, free = _a.free, isCurrent = _a.isCurrent, index = _a.index, label = _a.label, component = _a.component, goTo = _a.goTo, prev = _a.prev, next = _a.next, isLast = _a.isLast, autoScroll = _a.autoScroll, sx = _a.sx, other = __rest(_a, ["disabled", "done", "free", "isCurrent", "index", "label", "component", "goTo", "prev", "next", "isLast", "autoScroll", "sx"]);
    var $root;
    var isCurrentRef = useRef();
    var isClickable = function () { return !isCurrent && !disabled; };
    var scrollTop = function () {
        $root === null || $root === void 0 ? void 0 : $root.scrollIntoView({ behavior: 'smooth', block: 'start' });
    };
    useEffect(function () {
        isCurrentRef.current = isCurrent;
    }, [isCurrent]);
    useEffect(function () {
        if (autoScroll && !isCurrentRef.current && isCurrent)
            setTimeout(scrollTop, animationDuration);
    });
    return (React.createElement(Box, __assign({ sx: __assign({ '&:not(:first-of-type)': {
                borderTop: function (t) { return "1px solid ".concat(t.palette.divider); },
            } }, sx), ref: function (node) { return $root = node !== null && node !== void 0 ? node : undefined; } }, other),
        React.createElement(Box, { sx: __assign(__assign({ transition: function (t) { return t.transitions.create('all'); }, py: 0, px: 3, height: 68, display: 'flex', alignItems: 'center', fontSize: function (t) { return t.typography.subtitle1.fontSize; } }, isCurrent && {
                fontSize: function (t) { return t.typography.h6.fontSize; },
            }), isClickable() && {
                cursor: 'pointer',
                '&:hover': {
                    background: function (t) { return t.palette.background.default; },
                }
            }), onClick: function () { return goTo(index); } },
            !free && done && !isCurrent && (React.createElement(Icon, { sx: {
                    fontWeight: function (t) { return t.typography.fontWeightMedium; },
                    borderRadius: '50%',
                    color: colorSuccess,
                    mr: 1,
                } }, "check")),
            !free && React.createElement(React.Fragment, null,
                index + 1,
                ". "),
            label),
        React.createElement(Collapse, { in: isCurrent, timeout: animationDuration, sx: {
                transition: function (t) { return t.transitions.create('all'); },
                overflow: 'hidden',
            } },
            React.createElement(Box, { sx: {
                    pt: 0,
                    px: 3,
                    pb: 0,
                } }, React.cloneElement(component, { prev: prev, next: next, goTo: goTo, free: free, index: index, disabled: disabled, done: done, isCurrent: isCurrent, isLast: isLast })))));
};

==> mui-extension-4.2.0.tgz: package/lib/ExpensionStepper/ExpensionStep.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import { useEffect, useRef } from 'react';
import { Box, Collapse, Icon } from '@mui/material';
import { colorSuccess } from '../_core/style/color';
var animationDuration = 300;
export var ExpensionStep = function (_a) {
    var disabled = _a.disabled, done = _a.done, free = _a.free, isCurrent = _a.isCurrent, index = _a.index, label = _a.label, component = _a.component, goTo = _a.goTo, prev = _a.prev, next = _a.next, isLast = _a.isLast, autoScroll = _a.autoScroll, sx = _a.sx, other = __rest(_a, ["disabled", "done", "free", "isCurrent", "index", "label", "component", "goTo", "prev", "next", "isLast", "autoScroll", "sx"]);
    var $root;
    var isCurrentRef = useRef();
    var isClickable = function () { return !isCurrent && !disabled; };
    var scrollTop = function () {
        $root === null || $root === void 0 ? void 0 : $root.scrollIntoView({ behavior: 'smooth', block: 'start' });
    };
    useEffect(function () {
        isCurrentRef.current = isCurrent;
    }, [isCurrent]);
    useEffect(function () {
        if (autoScroll && !isCurrentRef.current && isCurrent)
            setTimeout(scrollTop, animationDuration);
    });
    return (React.createElement(Box, __assign({ sx: __assign({ '&:not(:first-of-type)': {
                borderTop: function (t) { return "1px solid " + t.palette.divider; },
            } }, sx), ref: function (node) { return $root = node !== null && node !== void 0 ? node : undefined; } }, other),
        React.createElement(Box, { sx: __assign(__assign({ transition: function (t) { return t.transitions.create('all'); }, py: 0, px: 3, height: 68, display: 'flex', alignItems: 'center', fontSize: function (t) { return t.typography.subtitle1.fontSize; } }, isCurrent && {
                fontSize: function (t) { return t.typography.h6.fontSize; },
            }), isClickable() && {
                cursor: 'pointer',
                '&:hover': {
                    background: function (t) { return t.palette.background.default; },
                }
            }), onClick: function () { return goTo(index); } },
            !free && done && !isCurrent && (React.createElement(Icon, { sx: {
                    fontWeight: function (t) { return t.typography.fontWeightMedium; },
                    borderRadius: '50%',
                    color: colorSuccess,
                    mr: 1,
                } }, "check")),
            !free && React.createElement(React.Fragment, null,
                index + 1,
                ". "),
            label),
        React.createElement(Collapse, { in: isCurrent, timeout: animationDuration, sx: {
                transition: function (t) { return t.transitions.create('all'); },
                overflow: 'hidden',
            } },
            React.createElement(Box, { sx: {
                    pt: 0,
                    px: 3,
                    pb: 0,
                } }, React.cloneElement(component, { prev: prev, next: next, goTo: goTo, free: free, index: index, disabled: disabled, done: done, isCurrent: isCurrent, isLast: isLast })))));
};
